@@ -1,5 +1,11 @@
 #ifndef LAST_H
 #define LAST_H
+#include <QtGui>
+#include <QXmlStreamReader>
+#include <QtXml>
+#include <QDomDocument>
+#include <QXmlStreamReader>
+#include <QMap>
 #include <QtNetwork>
 #include "last/requests.h"
 #include "last/utils.h"
