@@ -1,4 +1,11 @@
 #include "mainwindow.h"
+
+
+extern QSqlDatabase db;
+extern QString get_setting(QString);
+extern void set_setting(QString,QString);
+extern QString base_path;
+
 #ifdef Q_WS_MAEMO_5
 
 #include <QtMaemo5>
@@ -126,20 +133,6 @@ int t=0;
 
 MainWindow::MainWindow(QWidget *parent)    : QMainWindow(parent)
 {
-#ifdef Q_WS_MAEMO_5
-base_path="/home/user/";
-#else
-#ifdef Q_OS_WIN32
-base_path=qApp->applicationDirPath()+"/";
-#else
-#ifdef Q_WS_S60
-base_path="/data/tplayer/";
-#else
-base_path="/usr/share/tplayer/";
-#endif
-#endif
-#endif
-
 
 
 metaInformationResolver = new Phonon::MediaObject(this);
@@ -164,7 +157,7 @@ foreach (Phonon::EffectDescription effectDescription, effectDescriptions)
         if ((effectDescription.name() == "KEqualizer") || (effectDescription.name() == "equalizer-10bands"))
         {
 
-          //  ui.pushButton_5->setEnabled(true);
+            ui.pushButton_5->setEnabled(true);
             eqEffect = new Phonon::Effect(effectDescription);
 
         }
@@ -213,23 +206,6 @@ rotate=0;
 load();
 
 
-//opt->load(rotate,ui.listWidget->font().toString(),listWidget->font().pointSize());
-
-
-/*
- old style menu
-mmenu=new QMenu ();
-QMenu *mmenut=new QMenu ("Tools");
-mmenut->addAction("Download art",this,SLOT(dart()));
-mmenut->addAction("Download all art",this,SLOT(dart2()));
-mmenu->addAction("Information",this,SLOT(inform()));
-mmenu->addMenu(mmenut);
-mmenut->addAction("Options",opt,SLOT(exec()));
-mmenu->addAction("About",this,SLOT(about()));
-mmenu->addAction("Quit",qApp,SLOT(quit()));
-
-
-*/
 
 //new style
 ui.frame_10->hide();
@@ -279,42 +255,20 @@ click1();
 
 
 
-
-
-
-//new SQLite driven engine
-// to test
-int row=-1;
-
-     db = QSqlDatabase::addDatabase("QSQLITE");
-     db.setDatabaseName(base_path+"tplayer-list");
-
-     if(db.open()){
-     QStringList dbtables = db.tables(QSql::Tables);
-             if (dbtables.contains( tr("tracks"),
-                                    Qt::CaseInsensitive)) {
-
-}else{
-
-
-    QSqlQuery sql = QSqlQuery(db);
-    sql.exec(
-                 "create table tracks ( "
-                 "  path char(255) not null unique, "
-                 "  title char(255) , "
-                 "  artist char(255) , "
-                 "  genre char(255) , "
-                 "  album char(255) , "
-                 "  year char(255)  )" );
-}
-}else{
-    QMessageBox::critical(this, QObject::tr("Database Error"),db.lastError().text());
-}
-
 reload();
+int row=-1;
+QString rw=get_setting("last_played");
+if (!rw.trimmed().isEmpty()){
+    QMapIterator<int,QStringList> idk(list);
+    while(idk.hasNext()&&row==-1){
+        idk.next();
+        if (idk.value().at(0)==rw)row=idk.key();
+        }
+}
+
 ui.listWidget->setCurrentRow(row);
 
-
+inet_source=0;
 if (row!=-1)
  moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
 
@@ -339,22 +293,20 @@ for (int i=0;i<widgets.count();i++)
      widgets.at(i)->installEventFilter(this);
 
 
-if (on_start==1){
-    next();
-    // should save previous song name and start it
-    // not the first
+if (row!=-1){
+    if (on_start==1) play_pause();
+    if (on_start==2 && QDBusInterface ("org.freedesktop.Hal",
+                    "/org/freedesktop/Hal/devices/platform_headphone",
+                    "org.freedesktop.Hal.Device",
+                    QDBusConnection::systemBus()).call ("GetProperty", "button.state.value").arguments().at(0).toBool())play_pause();
 }
 }
 
 void MainWindow::reload(){
-    QFile file(base_path+".tplayer-list");
-         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    currentQuery=get_setting("query");
+    if (currentQuery.trimmed().isEmpty())
            currentQuery="SELECT * FROM tracks WHERE 1";
-       }else{
-           currentQuery=file.readLine();
 
-           file.close();
-       }
 
 
 QFile file2(base_path+".tplayer-lists");
@@ -536,47 +488,41 @@ void MainWindow::toggleEqualizer(bool val)
 
 
 void MainWindow::load(){
-
-    QFile file(base_path+".tplayerrc");
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-    {
-
-                rotate=0;
-                QFont h("Nokia Sans,18,-1,5,50,0,0,0,0,0");
-
-                h.setPointSize(10);
-                ui.listWidget->setFont(h);
-                namefilter=QString("*.mp3 *.flack *.ogg").split(" ");
-
-    scrobler=new last("","");
-
-    iload=0;
-    on_head_dis=0;
-    on_head_con=0;
-    on_start=0;
-
-              return;
-            }
+    rotate=get_setting("rotate").toLong();
+    QString fnt=get_setting("font");
+    if (fnt.isEmpty())fnt="Nokia Sans,18,-1,5,50,0,0,0,0,0";
+    QFont h(fnt);
 
 
-            QStringList tyu=QString(file.readAll()).split("\n");
-            while (tyu.count()<10)tyu.append("");
+    int size=get_setting("font_size").toLong();
+    if (size==0)size=10;
+    h.setPointSize(size);
 
-            rotate=tyu.at(0).toLong();
-            QFont h(tyu.at(1));
 
-            h.setPointSize(tyu.at(2).toLong());
-            ui.listWidget->setFont(h);
-            namefilter=QString(tyu.at(3)).split(" ");
+    ui.listWidget->setFont(h);
 
-scrobler=new last(tyu.at(4),tyu.at(5));
+    QString filter=get_setting("filter");
+    if (filter.isEmpty())filter="*.mp3 *.flack *.ogg";
+    namefilter=filter.split(" ");
 
-iload=QString(tyu.at(6)).toLong();
-on_head_dis=QString(tyu.at(7)).toLong();
-on_head_con=QString(tyu.at(8)).toLong();
-on_start=QString(tyu.at(9)).toLong();
+scrobler=new last(get_setting("last_login"),get_setting("last_password"));
+
+iload=get_setting("internet_load").toLong();
+on_head_dis=get_setting("head_disconnect").toLong();
+on_head_con=get_setting("head_connect").toLong();
+on_start=get_setting("start_action").toLong();
+
+
+QString bname=get_setting("FMTX-name");
+if (bname.isEmpty())bname="N900";
+ui.lineEdit->setText(bname);
+bname=get_setting("FMTX-text");
+if (bname.isEmpty())bname="%artist - %track";
+ui.lineEdit_2->setText(bname);
+double freq=get_setting("FMTX-freq").toDouble();
+if (freq<88)freq=88.1;
+ui.doubleSpinBox->setValue(freq);
 
-file.close();
 #ifdef Q_WS_MAEMO_5
  if (rotate==2){
  this-> setAttribute(Qt::WA_Maemo5AutoOrientation, true);
@@ -659,6 +605,7 @@ dg->exec();
 void MainWindow::fmtx_change(int state){
     try{
 
+
     if (state==Qt::Checked){
         // enable
 
@@ -703,6 +650,13 @@ void MainWindow::fmtx_change(int state){
 
 MainWindow::~MainWindow()
 {
+set_setting("last_played",list.value(ui.listWidget->currentRow()).at(0) );
+
+set_setting("FMTX-name",ui.lineEdit->text());
+set_setting("FMTX-text",ui.lineEdit_2->text());
+set_setting("FMTX-freq",QString("%1").arg(ui.doubleSpinBox->value()));
+
+
 db.commit();
 db.close();
 }
@@ -849,6 +803,7 @@ void MainWindow::play_pause(){
 
 void MainWindow::currentItemChanged ( QListWidgetItem * current ){
     if (inet_source==0){
+       emit track_change(list.value(ui.listWidget->row(current)).at(0));
     if (moo->currentTime()/moo->totalTime()>0.5)
         scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());}else inet_source=0;
     moo->setCurrentSource(list.value(ui.listWidget->row(current)).at(0));
@@ -1144,14 +1099,7 @@ void MainWindow::alistload(){
     QAction *t=(QAction *)sender();
 currentQuery=autolist.value(t->text());
 
-QFile file(base_path+".tplayer-list");
-     if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
-         return;
-
-
-    file.write(currentQuery.trimmed().toAscii());
-    file.close();
-
+set_setting("query",currentQuery.trimmed());
 
 drawlist();
 }
